@@ -30,7 +30,7 @@ class Pumpkin(Cube):
         return (
             super()
             .get_block_model(block, down, up, north, east, south, west, transparency)
-            .rotate(0, block.properties["direction"].value)
+            .rotate(0, block.properties["direction"].py_data)
         )
 
 
